package com.caimei365.manager.controller;

import com.caimei365.manager.config.security.ConstantKey;
import com.caimei365.manager.config.security.JwtService;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.SysMenu;
import com.caimei365.manager.entity.SysUser;
import com.caimei365.manager.service.SysUserService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/12/2
 */
@RestController
@RequestMapping("/sys")
public class SysUserApi {

    @Resource
    private SysUserService sysUserService;
    @Resource
    private JwtService jwtService;

    /**
     * 获取用户信息
     */
    @GetMapping("/user/info")
    public ResponseJson<SysUser> getUserInfo(HttpServletRequest request) {
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return sysUserService.getInfoByUsername(username);
    }

    /**
     * 获取菜单列表
     *
     * @param parentId 父级菜单Id
     * @param level    菜单层级
     * @param status   状态：0启用，1停用
     * @param pageNum  页码
     * @param pageSize 每页大小
     */
    @GetMapping("/menu/list")
    public ResponseJson<PaginationVo<SysMenu>> menuList(Integer parentId, Integer level, Integer status,
            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
            @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return sysUserService.getMenuList(parentId, level, status, pageNum, pageSize);
    }

    /**
     * 根据ID获取菜单
     */
    @GetMapping("/menu/{id}")
    public ResponseJson<SysMenu> getMenu(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        return sysUserService.getMenu(id);
    }

    /**
     * 根据ID更新菜单
     */
    @PostMapping("/menu/update/{id}")
    public ResponseJson<Void> updateMenu(@PathVariable("id") Integer id, SysMenu menu) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        return sysUserService.updateMenu(id, menu);
    }

    /**
     * 根据ID删除菜单
     */
    @PostMapping("/menu/delete/{id}")
    public ResponseJson<Void> deleteMenu(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        return sysUserService.deleteMenu(id);
    }










    /**
     * 退出登录
     */
    @PostMapping("/user/logout")
    public ResponseJson<Void> logout(HttpServletRequest request) {
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        return sysUserService.logout(token);
    }

    /**
     * 注册接口
     */
    @PostMapping("/user/register")
    public ResponseJson<SysUser> register(SysUser sysUser) {
        return sysUserService.register(sysUser);
    }

//    /**
//     * 测试公开接口
//     */
//    @GetMapping("/hello")
//    public ResponseJson<Void> hello() {
//        return ResponseJson.success("访问成功！公开接口：/hello",null);
//    }
//
//    /**
//     * 测试需要认证的接口
//     */
//    @GetMapping("/private")
//    public ResponseJson<Void> hello2() {
//        return ResponseJson.success("访问成功！非公开接口：/private", null);
//    }
}
